==> nomachine-7.8.2-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/NXHostsManager.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2022 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub BEGIN{no warnings;require NXMsg;do{"\x4e\x58\x4d\x73\x67"->import};}sub 
NXHostsManager::put{package NXHostsManager;no warnings;return (__put (@_));}sub 
NXHostsManager::del{package NXHostsManager;no warnings;return (__del (@_));}sub 
NXHostsManager::list{package NXHostsManager;no warnings;return (show (@_));}sub 
NXHostsManager::edit{package NXHostsManager;no warnings;return (__edit (@_));}
sub NXHostsManager::show{package NXHostsManager;no warnings;(my (@hosts)=__list 
(@_));main::nxwrite (main::nxgetSTDOUT (),"\x0a");main::nxwrite (
main::nxgetSTDOUT (),
"\x43\x6c\x69\x65\x6e\x74\x20\x49\x50\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x52\x65\x64\x69\x72\x65\x63\x74\x65\x64\x20\x74\x6f\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x4d\x6f\x64\x65\x0a"
);main::nxwrite (main::nxgetSTDOUT (),("\x2d" x (0x12c0+ 420-0x1446)),"\x20",(
"\x2d" x (0x0cbd+ 3832-0x1b97)),"\x20",("\x2d" x (0x0208+ 4811-0x14be)),"\x0a");
foreach my $host (@hosts){chomp ($host);($host=~ s/\r//g );(my ($client,
$redirect,$auth)=split ( /,/ ,$host,(0x0d44+ 4012-0x1cec)));($client=sprintf (
"\x25\x2d\x33\x30\x73",$client));($redirect=sprintf ("\x25\x2d\x33\x30\x73",
$redirect));($auth=sprintf ("\x25\x2d\x32\x31\x73",($auth.
"\x20\x61\x75\x74\x68\x65\x6e\x74\x69\x63\x61\x74\x69\x6f\x6e")));main::nxwrite 
(main::nxgetSTDOUT (),((((($client."\x20").$redirect)."\x20").$auth)."\x0a"));}
main::nxwrite (main::nxgetSTDOUT (),"\x0a");}sub NXHostsManager::__put{package 
NXHostsManager;no warnings;(my (@fields)=@_);NXRedis::sendToDb (((((((((((
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x68\x6d\x73\x65\x74\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x68\x6f\x73\x74\x73\x2e"
.$fields[(0x025c+ 8795-0x24b7)]).
"\x2c\x66\x69\x65\x6c\x64\x3d\x63\x6c\x69\x65\x6e\x74\x2c\x76\x61\x6c\x75\x65\x3d"
).$fields[(0x0773+ 987-0x0b4e)]).
"\x2c\x66\x69\x65\x6c\x64\x3d\x72\x65\x64\x69\x72\x65\x63\x74\x2c\x76\x61\x6c\x75\x65\x3d"
).$fields[(0x0029+ 7368-0x1cf0)])."\x3a").$fields[(0x08f0+ 7649-0x26cf)]).
"\x2c\x66\x69\x65\x6c\x64\x3d\x61\x75\x74\x68\x2c\x76\x61\x6c\x75\x65\x3d").
$fields[(0x058a+ 1462-0x0b3d)])."\x0a"));NXRedis::sendToDb (((
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x73\x61\x64\x64\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x68\x6f\x73\x74\x73\x2c\x76\x61\x6c\x75\x65\x3d"
.$fields[(0x1114+ 4370-0x2226)])."\x0a"));return ((0x0d5d+ 1942-0x14f2));}sub 
NXHostsManager::__del{package NXHostsManager;no warnings;(my $clientIpToDelete=
shift (@_));if (checkClientRedirectExist ($clientIpToDelete)){NXRedis::sendToDb 
(((
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x73\x72\x65\x6d\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x68\x6f\x73\x74\x73\x2c\x76\x61\x6c\x75\x65\x3d"
.$clientIpToDelete)."\x0a"));NXRedis::sendToDb (((
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x64\x65\x6c\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x68\x6f\x73\x74\x73\x2e"
.$clientIpToDelete)."\x0a"));return ((0x0825+ 5253-0x1ca9));}else{return (
(0x1e67+ 1483-0x2432));}}sub NXHostsManager::__list{package NXHostsManager;no 
warnings;(my $clientIpToFind=shift (@_));(my (@hosts)=());if ($clientIpToFind){
NXRedis::sendToDb (((
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x68\x6d\x67\x65\x74\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x68\x6f\x73\x74\x73\x2e"
.$clientIpToFind).
"\x2c\x66\x69\x65\x6c\x64\x3d\x63\x6c\x69\x65\x6e\x74\x2c\x66\x69\x65\x6c\x64\x3d\x72\x65\x64\x69\x72\x65\x63\x74\x2c\x66\x69\x65\x6c\x64\x3d\x61\x75\x74\x68\x0a"
));(my $line=NXRedis::get ());($line=~ s/ /,/g );push (@hosts,$line);}else{
NXRedis::sendToDb (
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x73\x6d\x65\x6d\x62\x65\x72\x73\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x68\x6f\x73\x74\x73\x0a"
);(my (@hostList)=split ( / / ,NXRedis::get (),(0x12da+ 1495-0x18b1)));foreach 
$host (@hostList){NXRedis::sendToDb (((
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x68\x6d\x67\x65\x74\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x68\x6f\x73\x74\x73\x2e"
.$host).
"\x2c\x66\x69\x65\x6c\x64\x3d\x63\x6c\x69\x65\x6e\x74\x2c\x66\x69\x65\x6c\x64\x3d\x72\x65\x64\x69\x72\x65\x63\x74\x2c\x66\x69\x65\x6c\x64\x3d\x61\x75\x74\x68\x0a"
));(my $line=NXRedis::get ());($line=~ s/ /,/g );push (@hosts,$line);}}return (
@hosts);}sub NXHostsManager::__edit{package NXHostsManager;no warnings;(my $client
=shift (@_));(my $host=shift (@_));(my $port=shift (@_));(my $switch=shift (@_))
;if (checkClientRedirectExist ($client)){if ((defined ($host)and defined ($port)
)){NXRedis::sendToDbAndSave (((((((
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x68\x73\x65\x74\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x68\x6f\x73\x74\x73\x2e"
.$client).
"\x2c\x66\x69\x65\x6c\x64\x3d\x72\x65\x64\x69\x72\x65\x63\x74\x2c\x76\x61\x6c\x75\x65\x3d"
).$host)."\x3a").$port)."\x0a"));}if (defined ($switch)){
NXRedis::sendToDbAndSave (((((
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x68\x73\x65\x74\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x68\x6f\x73\x74\x73\x2e"
.$client).
"\x2c\x66\x69\x65\x6c\x64\x3d\x61\x75\x74\x68\x2c\x76\x61\x6c\x75\x65\x3d").
$switch)."\x0a"));}}NXMsg::send_response (
"\x69\x48\x6f\x73\x74\x45\x64\x69\x74\x65\x64",
"\x4e\x58\x48\x6f\x73\x74\x73\x4d\x61\x6e\x61\x67\x65\x72",$client);return (
(0x0a8c+ 2054-0x1291));}sub NXHostsManager::checkClientRedirectExist{package 
NXHostsManager;no warnings;(my $client=shift (@_));NXRedis::sendToDb (((
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x65\x78\x69\x73\x74\x73\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x68\x6f\x73\x74\x73\x2e"
.$client)."\x0a"));(my $result=NXRedis::get ());if (($result==
(0x00a6+ 1682-0x0737))){Logger::debug ((("\x48\x6f\x73\x74\x3a\x20\x27".$client)
."\x27\x20\x65\x78\x69\x73\x74\x73\x2e"));}return ($result);}sub 
NXHostsManager::getClientRedirectBeforeAuth{package NXHostsManager;no warnings;(my $client
=shift (@_));return (__getClientRedirect ($client,(0x02b2+ 6058-0x1a5b)));}sub 
NXHostsManager::getClientRedirectAfterAuth{package NXHostsManager;no warnings;(my $client
=shift (@_));return (__getClientRedirect ($client,(0x0331+ 2618-0x0d6b)));}sub 
NXHostsManager::__getClientRedirect{package NXHostsManager;no warnings;(my $client
=shift (@_));(my $authbeforelogin=shift (@_));my (@hostTab);my (@ipTab);(my $all
=(0x06c5+ 3826-0x15b7));if (NXLicense::isNotRedirectFeature ()){return (
(0x025d+ 1432-0x07f5));}(my (@hostlist)=__list ());foreach my $hostline (
@hostlist){($hostline=~ s/\n//g );(my (@line)=split ( /,/ ,$hostline,
(0x0fd1+ 1911-0x1748)));if ((($line[(0x004a+ 5339-0x1525)]eq "\x2a")or ($line[
(0x02d1+ 6764-0x1d3d)]eq "\x2a\x2e\x2a\x2e\x2a\x2e\x2a"))){if (((
$authbeforelogin and ($line[(0x0124+ 1436-0x06be)]eq "\x62\x65\x66\x6f\x72\x65")
)or ((not ($authbeforelogin))and ($line[(0x0f7c+ 2846-0x1a98)]eq 
"\x61\x66\x74\x65\x72")))){($all=$line[(0x11aa+ 1711-0x1858)]);}}elsif (($line[
(0x19e4+ 110-0x1a52)]=~ /^[0-9\*\.]{1,15}$/ )){if ((($authbeforelogin and ($line
[(0x11e1+ 5257-0x2668)]eq "\x62\x65\x66\x6f\x72\x65"))or ((not ($authbeforelogin
))and ($line[(0x0cd8+ 944-0x1086)]eq "\x61\x66\x74\x65\x72")))){push (@ipTab,[
$line[(0x00e3+ 6127-0x18d2)],$line[(0x0543+ 6593-0x1f03)],$line[
(0x03d7+ 6160-0x1be5)]]);}}else{if ((($authbeforelogin and ($line[
(0x1755+ 1389-0x1cc0)]eq "\x62\x65\x66\x6f\x72\x65"))or ((not ($authbeforelogin)
)and ($line[(0x1f92+ 1230-0x245e)]eq "\x61\x66\x74\x65\x72")))){push (@hostTab,[
$line[(0x0ac3+ 6658-0x24c5)],$line[(0x0bdd+ 4565-0x1db1)],$line[
(0x1358+ 4178-0x23a8)]]);}}}(my $regEx=(""));foreach my $ipLine (@ipTab){(my (
@pieces)=split ( /\./ ,@{$ipLine;}[(0x0b66+ 4754-0x1df8)],(-
(0x1a37+ 2389-0x238b))));(my $piecesCount=scalar (@pieces));($regEx=@{$ipLine;}[
(0x1a56+ 893-0x1dd3)]);if (($piecesCount<(0x25c9+ 229-0x26aa))){if (($pieces[
(0x2173+ 1415-0x26fa)]=~ /^\*/ )){($regEx=("\x2e\x7b\x30\x2c\x7d".$regEx));}if (
($pieces[$piecesCount-(0x07e4+ 5687-0x1e1a)]=~ /\*$/ )){($regEx.=
"\x2e\x7b\x30\x2c\x7d");}}($regEx=~ s/\*/(|[0-9]|[0-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5])/g )
;if (($client=~ /^($regEx)$/ )){return (@{$ipLine;}[(0x2467+  51-0x2499)]);}}
foreach my $hostLine (@hostTab){(my (@ipdata)=split ( /\./ ,$client,
(0x0f20+   5-0x0f25)));(my $ippacked=pack ("\x43\x34",@ipdata));(my $host=
gethostbyaddr ($ippacked,(0x09e0+ 4109-0x19eb)));if ((@{$hostLine;}[
(0x0057+ 663-0x02ee)]=~ /^\*/ )){(@{$hostLine;}[(0x1c41+ 1880-0x2399)]=~ s/^\*// )
;}else{(@{$hostLine;}[(0x0ccd+ 993-0x10ae)]=("\x5e".@{$hostLine;}[
(0x05d4+ 7240-0x221c)]));}if ((@{$hostLine;}[(0x0745+ 633-0x09be)]=~ /\*$/ )){(@
{$hostLine;}[(0x1cf9+ 1928-0x2481)]=~ s/\*$// );}else{(@{$hostLine;}[
(0x0e17+ 2692-0x189b)]=(@{$hostLine;}[(0x0610+ 476-0x07ec)]."\x24"));}if (($host
=~ @{$hostLine;}[0] )){return (@{$hostLine;}[(0x0607+ 6362-0x1ee0)]);}}if ($all)
{return ($all);}Logger::debug (((
"\x43\x61\x6e\x6e\x6f\x74\x20\x62\x65\x20\x66\x6f\x75\x6e\x64\x20\x63\x6c\x69\x65\x6e\x74\x20\x49\x50\x3a\x20\x27"
.$client)."\x27\x20\x69\x6e\x20\x68\x6f\x73\x74\x73\x2e\x64\x62\x2e"));return (
(0x028f+ 5258-0x1719));}package NXHostsManager;no warnings;
NXMsg::register_response (
"\x4e\x58\x48\x6f\x73\x74\x73\x4d\x61\x6e\x61\x67\x65\x72",
"\x69\x48\x6f\x73\x74\x45\x64\x69\x74\x65\x64",(0x0b95+ 5551-0x20b5));
"\x3f\x3f\x3f";

==> nomachine-7.9.2-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/NXHostsManager.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2022 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub BEGIN{no warnings;require NXMsg;do{"\x4e\x58\x4d\x73\x67"->import};}sub 
NXHostsManager::put{package NXHostsManager;no warnings;return (__put (@_));}sub 
NXHostsManager::del{package NXHostsManager;no warnings;return (__del (@_));}sub 
NXHostsManager::list{package NXHostsManager;no warnings;return (show (@_));}sub 
NXHostsManager::edit{package NXHostsManager;no warnings;return (__edit (@_));}
sub NXHostsManager::show{package NXHostsManager;no warnings;(my (@hosts)=__list 
(@_));main::nxwrite (main::nxgetSTDOUT (),"\x0a");main::nxwrite (
main::nxgetSTDOUT (),
"\x43\x6c\x69\x65\x6e\x74\x20\x49\x50\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x52\x65\x64\x69\x72\x65\x63\x74\x65\x64\x20\x74\x6f\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x4d\x6f\x64\x65\x0a"
);main::nxwrite (main::nxgetSTDOUT (),("\x2d" x (0x1bc1+ 2808-0x269b)),"\x20",(
"\x2d" x (0x0b22+ 3893-0x1a39)),"\x20",("\x2d" x (0x0033+ 4512-0x11be)),"\x0a");
foreach my $host (@hosts){chomp ($host);($host=~ s/\r//g );(my ($client,
$redirect,$auth)=split ( /,/ ,$host,(0x0e5a+ 4234-0x1ee0)));($client=sprintf (
"\x25\x2d\x33\x30\x73",$client));($redirect=sprintf ("\x25\x2d\x33\x30\x73",
$redirect));($auth=sprintf ("\x25\x2d\x32\x31\x73",($auth.
"\x20\x61\x75\x74\x68\x65\x6e\x74\x69\x63\x61\x74\x69\x6f\x6e")));main::nxwrite 
(main::nxgetSTDOUT (),((((($client."\x20").$redirect)."\x20").$auth)."\x0a"));}
main::nxwrite (main::nxgetSTDOUT (),"\x0a");}sub NXHostsManager::__put{package 
NXHostsManager;no warnings;(my (@fields)=@_);NXRedis::sendToDb (((((((((((
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x68\x6d\x73\x65\x74\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x68\x6f\x73\x74\x73\x2e"
.$fields[(0x01e6+ 5773-0x1873)]).
"\x2c\x66\x69\x65\x6c\x64\x3d\x63\x6c\x69\x65\x6e\x74\x2c\x76\x61\x6c\x75\x65\x3d"
).$fields[(0x085b+ 2549-0x1250)]).
"\x2c\x66\x69\x65\x6c\x64\x3d\x72\x65\x64\x69\x72\x65\x63\x74\x2c\x76\x61\x6c\x75\x65\x3d"
).$fields[(0x1581+ 3337-0x2289)])."\x3a").$fields[(0x026a+ 3632-0x1098)]).
"\x2c\x66\x69\x65\x6c\x64\x3d\x61\x75\x74\x68\x2c\x76\x61\x6c\x75\x65\x3d").
$fields[(0x061c+ 4730-0x1893)])."\x0a"));NXRedis::sendToDb (((
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x73\x61\x64\x64\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x68\x6f\x73\x74\x73\x2c\x76\x61\x6c\x75\x65\x3d"
.$fields[(0x1079+ 5360-0x2569)])."\x0a"));return ((0x0566+ 546-0x0787));}sub 
NXHostsManager::__del{package NXHostsManager;no warnings;(my $clientIpToDelete=
shift (@_));if (checkClientRedirectExist ($clientIpToDelete)){NXRedis::sendToDb 
(((
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x73\x72\x65\x6d\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x68\x6f\x73\x74\x73\x2c\x76\x61\x6c\x75\x65\x3d"
.$clientIpToDelete)."\x0a"));NXRedis::sendToDb (((
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x64\x65\x6c\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x68\x6f\x73\x74\x73\x2e"
.$clientIpToDelete)."\x0a"));return ((0x1179+ 2300-0x1a74));}else{return (
(0x1396+ 2067-0x1ba9));}}sub NXHostsManager::__list{package NXHostsManager;no 
warnings;(my $clientIpToFind=shift (@_));(my (@hosts)=());if ($clientIpToFind){
NXRedis::sendToDb (((
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x68\x6d\x67\x65\x74\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x68\x6f\x73\x74\x73\x2e"
.$clientIpToFind).
"\x2c\x66\x69\x65\x6c\x64\x3d\x63\x6c\x69\x65\x6e\x74\x2c\x66\x69\x65\x6c\x64\x3d\x72\x65\x64\x69\x72\x65\x63\x74\x2c\x66\x69\x65\x6c\x64\x3d\x61\x75\x74\x68\x0a"
));(my $line=NXRedis::get ());($line=~ s/ /,/g );push (@hosts,$line);}else{
NXRedis::sendToDb (
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x73\x6d\x65\x6d\x62\x65\x72\x73\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x68\x6f\x73\x74\x73\x0a"
);(my (@hostList)=split ( / / ,NXRedis::get (),(0x076f+ 1107-0x0bc2)));foreach 
$host (@hostList){NXRedis::sendToDb (((
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x68\x6d\x67\x65\x74\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x68\x6f\x73\x74\x73\x2e"
.$host).
"\x2c\x66\x69\x65\x6c\x64\x3d\x63\x6c\x69\x65\x6e\x74\x2c\x66\x69\x65\x6c\x64\x3d\x72\x65\x64\x69\x72\x65\x63\x74\x2c\x66\x69\x65\x6c\x64\x3d\x61\x75\x74\x68\x0a"
));(my $line=NXRedis::get ());($line=~ s/ /,/g );push (@hosts,$line);}}return (
@hosts);}sub NXHostsManager::__edit{package NXHostsManager;no warnings;(my $client
=shift (@_));(my $host=shift (@_));(my $port=shift (@_));(my $switch=shift (@_))
;if (checkClientRedirectExist ($client)){if ((defined ($host)and defined ($port)
)){NXRedis::sendToDbAndSave (((((((
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x68\x73\x65\x74\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x68\x6f\x73\x74\x73\x2e"
.$client).
"\x2c\x66\x69\x65\x6c\x64\x3d\x72\x65\x64\x69\x72\x65\x63\x74\x2c\x76\x61\x6c\x75\x65\x3d"
).$host)."\x3a").$port)."\x0a"));}if (defined ($switch)){
NXRedis::sendToDbAndSave (((((
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x68\x73\x65\x74\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x68\x6f\x73\x74\x73\x2e"
.$client).
"\x2c\x66\x69\x65\x6c\x64\x3d\x61\x75\x74\x68\x2c\x76\x61\x6c\x75\x65\x3d").
$switch)."\x0a"));}}NXMsg::send_response (
"\x69\x48\x6f\x73\x74\x45\x64\x69\x74\x65\x64",
"\x4e\x58\x48\x6f\x73\x74\x73\x4d\x61\x6e\x61\x67\x65\x72",$client);return (
(0x0ea8+ 3182-0x1b15));}sub NXHostsManager::checkClientRedirectExist{package 
NXHostsManager;no warnings;(my $client=shift (@_));NXRedis::sendToDb (((
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x65\x78\x69\x73\x74\x73\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x68\x6f\x73\x74\x73\x2e"
.$client)."\x0a"));(my $result=NXRedis::get ());if (($result==
(0x0642+ 7066-0x21db))){Logger::debug ((("\x48\x6f\x73\x74\x3a\x20\x27".$client)
."\x27\x20\x65\x78\x69\x73\x74\x73\x2e"));}return ($result);}sub 
NXHostsManager::getClientRedirectBeforeAuth{package NXHostsManager;no warnings;(my $client
=shift (@_));return (__getClientRedirect ($client,(0x04d0+ 3320-0x11c7)));}sub 
NXHostsManager::getClientRedirectAfterAuth{package NXHostsManager;no warnings;(my $client
=shift (@_));return (__getClientRedirect ($client,(0x1dbc+ 595-0x200f)));}sub 
NXHostsManager::__getClientRedirect{package NXHostsManager;no warnings;(my $client
=shift (@_));(my $authbeforelogin=shift (@_));my (@hostTab);my (@ipTab);(my $all
=(0x1742+ 3371-0x246d));if (NXLicense::isNotRedirectFeature ()){return (
(0x18ab+ 527-0x1aba));}(my (@hostlist)=__list ());foreach my $hostline (
@hostlist){($hostline=~ s/\n//g );(my (@line)=split ( /,/ ,$hostline,
(0x022b+ 1449-0x07d4)));if ((($line[(0x091b+ 6186-0x2145)]eq "\x2a")or ($line[
(0x0773+ 2203-0x100e)]eq "\x2a\x2e\x2a\x2e\x2a\x2e\x2a"))){if (((
$authbeforelogin and ($line[(0x1329+ 2127-0x1b76)]eq "\x62\x65\x66\x6f\x72\x65")
)or ((not ($authbeforelogin))and ($line[(0x0712+ 2267-0x0feb)]eq 
"\x61\x66\x74\x65\x72")))){($all=$line[(0x0506+ 293-0x062a)]);}}elsif (($line[
(0x02f8+ 8157-0x22d5)]=~ /^[0-9\*\.]{1,15}$/ )){if ((($authbeforelogin and (
$line[(0x1053+ 1498-0x162b)]eq "\x62\x65\x66\x6f\x72\x65"))or ((not (
$authbeforelogin))and ($line[(0x0957+ 495-0x0b44)]eq "\x61\x66\x74\x65\x72")))){
push (@ipTab,[$line[(0x0932+ 816-0x0c62)],$line[(0x08f1+ 6919-0x23f7)],$line[
(0x148a+ 3103-0x20a7)]]);}}else{if ((($authbeforelogin and ($line[
(0x07c7+ 7561-0x254e)]eq "\x62\x65\x66\x6f\x72\x65"))or ((not ($authbeforelogin)
)and ($line[(0x14a5+ 4629-0x26b8)]eq "\x61\x66\x74\x65\x72")))){push (@hostTab,[
$line[(0x07a5+ 499-0x0998)],$line[(0x0789+ 2152-0x0ff0)],$line[
(0x17a4+ 2743-0x2259)]]);}}}(my $regEx=(""));foreach my $ipLine (@ipTab){(my (
@pieces)=split ( /\./ ,@{$ipLine;}[(0x01e1+ 8896-0x24a1)],(-
(0x1923+ 1283-0x1e25))));(my $piecesCount=scalar (@pieces));($regEx=@{$ipLine;}[
(0x1712+ 2693-0x2197)]);if (($piecesCount<(0x0a4f+ 913-0x0ddc))){if (($pieces[
(0x1afb+ 616-0x1d63)]=~ /^\*/ )){($regEx=("\x2e\x7b\x30\x2c\x7d".$regEx));}if ((
$pieces[$piecesCount-(0x1669+ 2605-0x2095)]=~ /\*$/ )){($regEx.=
"\x2e\x7b\x30\x2c\x7d");}}($regEx=~ s/\*/(|[0-9]|[0-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5])/g )
;if (($client=~ /^($regEx)$/ )){return (@{$ipLine;}[(0x07ec+ 1769-0x0ed4)]);}}
foreach my $hostLine (@hostTab){(my (@ipdata)=split ( /\./ ,$client,
(0x0bcd+ 6961-0x26fe)));(my $ippacked=pack ("\x43\x34",@ipdata));(my $host=
gethostbyaddr ($ippacked,(0x21c2+ 333-0x230d)));if ((@{$hostLine;}[
(0x074a+ 3307-0x1435)]=~ /^\*/ )){(@{$hostLine;}[(0x08d7+ 3152-0x1527)]=~ s/^\*// )
;}else{(@{$hostLine;}[(0x10cc+ 2420-0x1a40)]=("\x5e".@{$hostLine;}[
(0x0241+ 1710-0x08ef)]));}if ((@{$hostLine;}[(0x185d+ 1406-0x1ddb)]=~ /\*$/ )){(
@{$hostLine;}[(0x0026+ 8616-0x21ce)]=~ s/\*$// );}else{(@{$hostLine;}[
(0x0a49+  69-0x0a8e)]=(@{$hostLine;}[(0x03d2+ 3390-0x1110)]."\x24"));}if (($host
=~ @{$hostLine;}[0] )){return (@{$hostLine;}[(0x08af+ 4692-0x1b02)]);}}if ($all)
{return ($all);}Logger::debug (((
"\x43\x61\x6e\x6e\x6f\x74\x20\x62\x65\x20\x66\x6f\x75\x6e\x64\x20\x63\x6c\x69\x65\x6e\x74\x20\x49\x50\x3a\x20\x27"
.$client)."\x27\x20\x69\x6e\x20\x68\x6f\x73\x74\x73\x2e\x64\x62\x2e"));return (
(0x1caf+ 2578-0x26c1));}package NXHostsManager;no warnings;
NXMsg::register_response (
"\x4e\x58\x48\x6f\x73\x74\x73\x4d\x61\x6e\x61\x67\x65\x72",
"\x69\x48\x6f\x73\x74\x45\x64\x69\x74\x65\x64",(0x02f9+ 5980-0x19c6));
"\x3f\x3f\x3f";
